@@ -8,6 +8,7 @@ import struct
 import re
 import copy
 from collections import deque
+import datetime
 
 from ..aid.sixing import *
 from .globaling import INDENT_ADD, REO_IdentPub
@@ -94,14 +95,41 @@ class Store(registering.Registrar):
         #create share for stamp
         self.timeShr = self.create('.time').update(value = self.stamp or 0.0)
         #create share for realtime
-        self.realTimeShr = self.create('.realtime').update(value = time.time())
+        rt = time.time()
+        self.realTimeShr = self.create('.realtime').update(value=rt)
+        #create share for realtime datetime ascii
+        dt = datetime.datetime.fromtimestamp(rt)
+        self.dateTimeShr = self.create('.datetime').update([("iso", dt.isoformat()),
+                                                            ("dt", dt),
+                                                            ("year", dt.year),
+                                                            ("month", dt.month),
+                                                            ("day", dt.day),
+                                                            ("hour", dt.hour),
+                                                            ("minute", dt.minute),
+                                                            ("second", dt.second),
+                                                            ("micro", dt.microsecond)
+                                                           ])
 
     def changeStamp(self, stamp):
         """change time stamp for this store """
         try: #stamp must be a number or None
             self.stamp = float(stamp)
             self.timeShr.update(value=self.stamp)
-            self.realTimeShr.update(value=time.time())
+            rt = time.time()
+            self.realTimeShr.update(value=rt)
+            dt = datetime.datetime.fromtimestamp(rt)
+            self.dateTimeShr.update([("iso", dt.isoformat()),
+                                        ("dt", dt),
+                                        ("year", dt.year),
+                                        ("month", dt.month),
+                                        ("day", dt.day),
+                                        ("hour", dt.hour),
+                                        ("minute", dt.minute),
+                                        ("second", dt.second),
+                                        ("micro", dt.microsecond)
+                                       ])
+
+
         except TypeError:
             self.stamp = None
             console.verbose("Error: Store {0}, Invalid stamp '{1}'\n".format(
@@ -113,7 +141,20 @@ class Store(registering.Registrar):
         try:
             self.stamp += delta
             self.timeShr.update(value=self.stamp)
-            self.realTimeShr.update(value=time.time())
+            rt = time.time()
+            self.realTimeShr.update(value=rt)
+            dt = datetime.datetime.fromtimestamp(rt)
+            self.dateTimeShr.update([("iso", dt.isoformat()),
+                                        ("dt", dt),
+                                        ("year", dt.year),
+                                        ("month", dt.month),
+                                        ("day", dt.day),
+                                        ("hour", dt.hour),
+                                        ("minute", dt.minute),
+                                        ("second", dt.second),
+                                        ("micro", dt.microsecond)
+                                       ])
+
         except TypeError:
             console.verbose("Error: Store {0}, Can't advance stamp={1}"
                             " by delta={2}\n".format(self.name, self.stamp, delta))
@@ -361,7 +402,7 @@ class Mark(object):
         data = copy of data of associated share
 
     """
-    __slots__ = ('stamp', 'data',)
+    __slots__ = ('stamp', 'data', 'used')
 
 
     def __init__(self, *pa, **kwa):
@@ -370,6 +411,7 @@ class Mark(object):
 
         self.stamp = None
         self.data = None
+        self.used = None
 
 
 class Share(object):
@@ -478,7 +520,7 @@ class Share(object):
         if deck is not None:
             self.deck.extend(deck)
 
-        self.marks = odict() #odict of marks
+        self.marks = odict() #odict of marks keyed by unique marker id
 
 
     #make share look like a dictionary for .data record fields
@@ -578,7 +620,7 @@ class Share(object):
         Remove key and the associated item and return the associated value
         If key not found return default if given otherwise raise KeyError
         """
-        value = self._data.__dict__.pop(self, key, *default)
+        value = self._data.__dict__.pop(key, *default)
         return value
 
     def popitem(self):
@@ -593,7 +635,7 @@ class Share(object):
         If key in ._data, return value at key
         Otherwise set value at key to default and return default
         """
-        value = self._data.__dict__.setdefault(self, key, default)
+        value = self._data.__dict__.setdefault(key, default)
         return value
 
     def sift(self, fields=None):
